# Package description

The `rv_distributions` package provide classes and methods to create, represent and visualise different types of statistical distributions including:

* The Gaussian (normal) distribution
* The Binomial distribution

# Package dependencies
Description of dependencies this package rely on

# Files

Description of the files in the package

# Intallation

Description of how to install the package

# Usage

Description of how to use the package after installing

# To do
Here are listed work to be done next to extend this package
* Add the poisson distribution
* Add the gamma distribution
* Add the exponential distribution


# Kown issues

Description of known issues submitted by users

# How to contribute

Description of how to contribute to this package

# License

Description of the license and citations of this package


